summaryrefslogtreecommitdiff
path: root/test/ddd1.go
diff options
context:
space:
mode:
Diffstat (limited to 'test/ddd1.go')
-rw-r--r--test/ddd1.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/ddd1.go b/test/ddd1.go
index 4f830c582..6f714c078 100644
--- a/test/ddd1.go
+++ b/test/ddd1.go
@@ -13,8 +13,8 @@ var (
_ = sum()
_ = sum(1.0, 2.0)
_ = sum(1.5) // ERROR "integer"
- _ = sum("hello") // ERROR "convert"
- _ = sum([]int{1}) // ERROR "slice literal.*as type int"
+ _ = sum("hello") // ERROR "convert|incompatible"
+ _ = sum([]int{1}) // ERROR "slice literal.*as type int|incompatible"
)
type T []T